@@ -38,7 +38,7 @@ use constant (DATASET_HASH_LIMIT => 3000);
 		# region, and a hash returned with potentially a score for each basepair. 
 		# This may become unwieldy for very large regions, which may be better 
 		# served by separate database queries for each window.
-my $VERSION = '1.15';
+my $VERSION = '1.17';
 
 print "\n This script will collect binned values across genes to create an average gene\n\n";
 
@@ -1217,35 +1217,43 @@ __END__
 
 average_gene.pl
 
-A program to generate class average summaries for a list of genes or features.
+A program to generate class average summaries for a list of features.
 
 =head1 SYNOPSIS
  
- average_gene.pl --db <database> --feature <text> --out <file> [--options]
- 
- average_gene.pl --in <file> --out <file> [--options]
+ average_gene.pl [--options] <filename>
   
-  Options:
-  --in <filename> 
-  --out <filename>
+  Options for existing files:
+  --in <filename>
+  
+  Options for new files:
   --db <name | filename>
+  --feature <type | type:source | alias>, ...
+  
+  Options for data collection:
   --ddb <name | filename>
-  --feature <type | type:source | alias>,...
   --data <dataset_name | filename>
-  --method [mean|median|stddev|min|max|range|sum|rpm|rpkm]
-  --value [score|count|length]
-  --bins <integer>
-  --ext <integer>
+  --method [mean|median|stddev|min|max|range|sum|rpm|rpkm]  (mean)
+  --value [score|count|length]                              (score)
+  --strand [all|sense|antisense]                            (all)
+  --force_strand
+  --long
+  --(no)log
+  
+  Bin specification:
+  --bins <integer>                                          (10)
+  --ext <integer>                                           (0)
   --extsize <integer>
   --min <integer>
-  --strand [all|sense|antisense]
-  --long
+  
+  Post-processing:
   --sum
   --smooth
-  --force_strand
-  --(no)log
+  
+  General options:
+  --out <filename>
   --gz
-  --cpu <integer>
+  --cpu <integer>                                           (2)
   --version
   --help
 
@@ -1265,10 +1273,6 @@ first row should be column headers. Bed files are acceptable, as are
 text files generated by other B<BioToolBox> scripts. Files may be 
 gzipped compressed.
 
-=item --out <filename>
-
-Specify the output file name. 
-
 =item --db <name | filename>
 
 Specify the name of a C<Bio::DB::SeqFeature::Store> annotation database 
@@ -1279,13 +1283,6 @@ file), or when using an existing input file with the database indicated
 in the metadata. For more information about using annotation databases, 
 see L<https://code.google.com/p/biotoolbox/wiki/WorkingWithDatabases>. 
 
-=item --ddb <name | filename>
-
-If the data to be collected is from a second database that is separate 
-from the annotation database, provide the name of the data database here. 
-Typically, a second C<Bio::DB::SeqFeature::Store> or BigWigSet database 
-is provided here. 
-
 =item --feature <type | type:source | alias>,...
 
 Specify the type of feature from which to collect values. This is required 
@@ -1296,6 +1293,13 @@ C<biotoolbox.cfg> file and provide a shortcut to a list of one or more
 database features. More than one feature may be included as a 
 comma-delimited list (no spaces). 
   
+=item --ddb <name | filename>
+
+If the data to be collected is from a second database that is separate 
+from the annotation database, provide the name of the data database here. 
+Typically, a second C<Bio::DB::SeqFeature::Store> or BigWigSet database 
+is provided here. 
+
 =item --data <dataset_name | filename>
 
 Provide the name of the dataset to collect the values. If no 
@@ -1337,6 +1341,38 @@ BigBed and database features support count and length and optionally
 score; Bam files support basepair coverage (score), count (number of 
 alignments), and length.
 
+=item --strand [all|sense|antisense]
+
+Specify whether stranded data should be collected. Three values are 
+allowed: all datasets should be collected (default), only sense 
+datasets, or only antisense datasets should be collected.
+
+=item --force_strand
+
+For features that are not inherently stranded (strand value of 0)
+or that you want to impose a different strand, set this option when
+collecting stranded data. This will reassign the specified strand for
+each feature regardless of its original orientation. This requires the
+presence of a "strand" column in the input data file. This option only
+works with input file lists of database features, not defined genomic
+regions (e.g. BED files). Default is false.
+
+=item --long
+
+Indicate that the dataset from which scores are collected are 
+long features (counting genomic annotation for example) and not point 
+data (microarray data or sequence coverage). Normally long features are 
+only recorded at their midpoint, leading to inaccurate representation at 
+some windows. This option forces the program to collect data separately 
+at each window, rather than once for each file feature or region and 
+subsequently assigning scores to windows. Execution times may be 
+longer than otherwise. Default is false.
+
+=item --(no)log
+
+Dataset values are (not) in log2 space and should be treated 
+accordingly. Output values will be in the same space.
+
 =item --bins <integer>
 
 Specify the number of bins that will be generated over the length 
@@ -1362,23 +1398,6 @@ length below this value will not be skipped (all bins will have
 null values). This is to avoid having bin sizes below the average 
 microarray tiling distance. The default is undefined (no limit).
 
-=item --strand [all|sense|antisense]
-
-Specify whether stranded data should be collected. Three values are 
-allowed: all datasets should be collected (default), only sense 
-datasets, or only antisense datasets should be collected.
-
-=item --long
-
-Indicate that the dataset from which scores are collected are 
-long features (counting genomic annotation for example) and not point 
-data (microarray data or sequence coverage). Normally long features are 
-only recorded at their midpoint, leading to inaccurate representation at 
-some windows. This option forces the program to collect data separately 
-at each window, rather than once for each file feature or region and 
-subsequently assigning scores to windows. Execution times may be 
-longer than otherwise. Default is false.
-
 =item --sum
 
 Indicate that the data should be averaged across all features at
@@ -1391,20 +1410,9 @@ is false.
 Indicate that windows without values should (not) be interpolated
 from neighboring values. The default is false.
 
-=item --force_strand
+=item --out <filename>
 
-For features that are not inherently stranded (strand value of 0)
-or that you want to impose a different strand, set this option when
-collecting stranded data. This will reassign the specified strand for
-each feature regardless of its original orientation. This requires the
-presence of a "strand" column in the input data file. This option only
-works with input file lists of database features, not defined genomic
-regions (e.g. BED files). Default is false.
-
-=item --(no)log
-
-Dataset values are (not) in log2 space and should be treated 
-accordingly. Output values will be in the same space.
+Specify the output file name. 
 
 =item --gz
 
@@ -1438,6 +1446,39 @@ side). The bin size is determined as a percentage of gene length.
 The program writes out a tim data formatted text file. It will also 
 optionally generate a "summed" or average profile for all of the features. 
 
+=head1 EXAMPLES
+
+These are some examples of some common scenarios for collecting data.
+
+=over 4
+
+=item Collect scores in intervals
+
+You want to collect the mean score from a bigWig file in 10% intervals 
+across each feature in a Bed file.
+
+  average_gene.pl --data scores.bw --in input.bed
+
+=item Collect scores in intervals plus extended regions
+
+You want to collect the maximum score in 5% intervals across each each 
+feature as well as five 100 bp intervals outside of each interval.
+
+  average_gene.pl --bins 20 --method max --ext 5 --extsize 100 --data \
+  scores.bw --in input.txt
+
+=item Collect scores in intervals for genes
+
+You want to collect stranded alignment counts from a Bam file for genes 
+in an annotation database, then generate a profile graph.
+
+  average_gene.pl --db annotation --feature gene --strand sense --value \
+  count --method sum --data alignments.bam --out gene_profile --sum
+  
+  graph_profile.pl --in gene_profile_summed.txt --min 0 --max 100
+
+=back
+
 =head1 AUTHOR
 
  Timothy J. Parnell, PhD
