@@ -1,4 +1,4 @@
-#!/usr/bin/env perl
+#!/usr/bin/perl
 
 # documentation at end of file
 
@@ -15,7 +15,7 @@ use Bio::ToolBox::file_helper qw(
 );
 use Bio::ToolBox::db_helper::config qw($BTB_CONFIG add_program);
 use Bio::ToolBox::big_helper qw(wig_to_bigwig_conversion);
-my $VERSION = '1.14';
+my $VERSION = '1.15';
 
 print "\n This program will convert bar files to a wig file\n";
 
@@ -109,6 +109,16 @@ unless (defined $java) {
 	};
 	add_program($java) if $java; # remember this for next time
 }
+unless (defined $java) {
+	# typical location for java executable on a *nix environment
+	$java = File::Spec->catfile( File::Spec->rootdir, 'usr', 'bin', 'java');
+	if (-e $java and -x _) {
+		add_program($java);
+	}
+	else {
+		undef $java;
+	}
+}
 unless (defined $java) {
 	die " unable to identify java executable!\n";
 }
@@ -148,6 +158,7 @@ if ($bigwig) {
 		die "  Must define a database name or provide a chromosome file \n" . 
 			"to use the bigwig option! see help\n";
 	}
+	$gz = 0;
 }
 unless (defined $use_track) {
 	if ($bigwig) {
@@ -650,23 +661,25 @@ __END__
 
 =head1 NAME
 
-bam2gff_bed.pl
+bar2wig.pl
 
-A script to convert bam paired_reads to a gff or bed file.
+A script to convert bar files to wig files.
 
 =head1 SYNOPSIS
 
-bam2gff_bed.pl [--options...] <filename>
+bar2wig.pl [--options...] <filename>
   
   Options:
   --in <filename>
-  --bed | --gff | --bigbed | --bb
-  --pe
-  --type <text>
-  --source <text>
-  --randstr
   --out <filename> 
-  --bbapp </path/to/bedToBigBed>
+  --method [mean|median|sum|max]
+  --log
+  --track
+  --bw
+  --barapp </path/to/Bar2Gr>
+  --bwapp </path/to/wigToBigWig>
+  --db <database>
+  --chromof </path/to/chromosomes>
   --gz
   --version
   --help
@@ -688,12 +701,6 @@ Specify the output filename. By default it uses the base name of the
 input file or the input directory name. The output file will either 
 have a .wig or .bw file extension.
 
-=item --barapp </path/to/Bar2Gr>
-
-Specify the full path to David Nix's USeq or T2 application Bar2Gr (it 
-is included in both software packages). By default it uses the path 
-defined in the biotoolbox configuration file, biotoolbox.cfg.
-
 =item --method [mean | median | sum | max]
 
 Define the method used to combine multiple data values at a single 
@@ -723,17 +730,11 @@ generating bigWig files manually. The default is to include for wig files
 Flag to indicate that a binary bigWig file should be generated rather than 
 a text wig file.
 
-=item --db <database>
+=item --barapp </path/to/Bar2Gr>
 
-Specify the name of a Bio::DB database from which to extract chromosome 
-names and sizes. This information is required when generating a bigWig 
-file.
-
-=item --chromof <filename>
-
-Alternative to the --db argument, a pre-generated chromosome sizes text 
-file may be specified. This text file should consist of two columns, 
-delimited by whitespace, consisting of the chromosome name and size.
+Specify the full path to David Nix's USeq or T2 application Bar2Gr (it 
+is included in both software packages). By default it uses the path 
+defined in the biotoolbox configuration file, biotoolbox.cfg.
 
 =item --bwapp </path/to/wigToBigWig>
 
@@ -742,11 +743,24 @@ default it uses the path defined in the biotoolbox configuration file,
 biotoolbox.cfg. If it is not defined here or in the config file, then 
 the system path is searched for the executable. 
 
+=item --db <database>
+
+Specify the name of a C<Bio::DB::SeqFeature::Store> annotation database 
+or other indexed data file, e.g. Bam or bigWig file, from which chromosome 
+length information may be obtained. For more information about using databases, 
+see L<https://code.google.com/p/biotoolbox/wiki/WorkingWithDatabases>. It 
+is only required when generating a bigWig file.
+
+=item --chromof </path/to/chromosomes>
+
+Alternative to the --db argument, a pre-generated chromosome sizes text 
+file may be specified. This text file should consist of two columns, 
+delimited by whitespace, consisting of the chromosome name and size.
+
 =item --gz
 
 Specify whether (or not) the output wig file should be compressed with gzip.
-This option does not affect bigWig files, but will affect intermediate 
-wig files.
+Default is false.
 
 =item --version
 
