@@ -39,7 +39,7 @@ use constant (DATASET_HASH_LIMIT => 3000);
 		# region, and a hash returned with potentially a score for each basepair. 
 		# This may become unwieldy for very large regions, which may be better 
 		# served by separate database queries for each window.
-my $VERSION = '1.15';
+my $VERSION = '1.17';
 
 print "\n A script to collect windowed data flanking a relative position of a feature\n\n";
   
@@ -1292,31 +1292,39 @@ A script to collect data in bins around a relative position.
 
 =head1 SYNOPSIS
  
-get_relative_data.pl --db <database> --feature <name> --out <file> [--options]
-
 get_relative_data.pl --in <in_filename> --out <out_filename> [--options]
   
-  Options:
-  --db <name|file.gff3>
-  --ddb <name|file.gff3>
-  --feature [type, type:source]
+  Options for existing files:
   --in <filename> 
-  --out <filename>
+  
+  Options for new files:
+  --db <name|file>
+  --feature <type | type:source | alias>, ...
+  
+  Options for data collection:
+  --ddb <name|file>
   --data <dataset_name | filename>
-  --method [mean|median|min|max|stddev|sum|rpm]
-  --value [score|count|length]
-  --win <integer>
-  --num <integer>
-  --pos [5|3|m]
-  --strand [sense|antisense|all]
+  --method [mean|median|min|max|stddev|sum|rpm]             (mean)
+  --value [score|count|length]                              (score)
+  --strand [all|sense|antisense]                            (all)
   --force_strand
   --avoid
   --long
-  --(no)sum
-  --smooth
   --log
+  
+  Bin specification:
+  --win <integer>                                           (50)
+  --num <integer>                                           (20)
+  --pos [5|m|3]                                             (5)
+  
+  Post-processing:
+  --(no)sum                                                 (true)
+  --smooth
+  
+  General Options:
+  --out <filename>
   --gz
-  --cpu <integer>
+  --cpu <integer>                                           (2)
   --version
   --help
 
@@ -1326,28 +1334,6 @@ The command line flags and descriptions:
 
 =over 4
 
-=item --db <name | filename>
-
-Specify the name of a C<Bio::DB::SeqFeature::Store> annotation database 
-from which gene or feature annotation may be derived. A database is 
-required for generating new data files with features. This option may 
-skipped when using coordinate information from an input file (e.g. BED 
-file), or when using an existing input file with the database indicated 
-in the metadata. For more information about using annotation databases, 
-see L<https://code.google.com/p/biotoolbox/wiki/WorkingWithDatabases>. 
-
-=item --ddb <name | filename>
-
-If the data to be collected is from a second database that is separate 
-from the annotation database, provide the name of the data database here. 
-Typically, a second C<Bio::DB::SeqFeature::Store> or BigWigSet database 
-is provided here. 
-
-=item --out <filename>
-
-Specify the output file name. Required for new files; otherwise, 
-input files will be overwritten unless specified.
-
 =item --in <filename>
 
 Specify an input file containing either a list of database features or 
@@ -1358,6 +1344,21 @@ first row should be column headers. Bed files are acceptable, as are
 text files generated by other B<BioToolBox> scripts. Files may be 
 gzipped compressed.
 
+=item --out <filename>
+
+Specify the output file name. Required for new files; otherwise, 
+input files will be overwritten unless specified.
+
+=item --db <name | filename>
+
+Specify the name of a C<Bio::DB::SeqFeature::Store> annotation database 
+from which gene or feature annotation may be derived. A database is 
+required for generating new data files with features. This option may 
+skipped when using coordinate information from an input file (e.g. BED 
+file), or when using an existing input file with the database indicated 
+in the metadata. For more information about using annotation databases, 
+see L<https://code.google.com/p/biotoolbox/wiki/WorkingWithDatabases>. 
+
 =item --feature [type, type:source]
 
 Specify the type of feature to map data around. The feature may be 
@@ -1365,6 +1366,13 @@ listed either as GFF type or GFF type:source. The list
 of features will be automatically generated from the database. 
 This is only required when an input file is not specified. 
 
+=item --ddb <name | filename>
+
+If the data to be collected is from a second database that is separate 
+from the annotation database, provide the name of the data database here. 
+Typically, a second C<Bio::DB::SeqFeature::Store> or BigWigSet database 
+is provided here. 
+
 =item --data <dataset_name | filename>
 
 Specify the name of the data set from which you wish to 
@@ -1393,24 +1401,6 @@ support count and length and optionally score; Bam files support basepair
 coverage (score), count (number of alignments), and length. The default 
 value type is score. 
 
-=item --win <integer>
-
-Specify the window size. The default is 50 bp.
-
-=item --num <integer>
-
-Specify the number of windows on either side of the feature position 
-(total number will be 2 x [num]). The default is 20, or 1 kb on either 
-side of the reference position if the default window size is used.
-
-=item --pos [5|3|m]
-
-Indicate the relative position of the feature around which the 
-data is mapped. Three values are accepted: "5" indicates the 
-5' prime end is used, "3" indicates the 3' end is used, and "m" or "4"
-indicates the middle of the feature is used. The default is to 
-use the 5' end, or the start position of unstranded features. 
-
 =item --strand [sense|antisense|all]
 
 Specify whether stranded data should be collected for each of the 
@@ -1448,6 +1438,30 @@ at each window, rather than once for each file feature or region and
 subsequently assigning scores to windows. Execution times may be 
 longer than otherwise. Default is false.
 
+=item --log
+
+Dataset values are (not) in log2 space and should be treated 
+accordingly. Output values will be in the same space. The default is 
+false (nolog).
+
+=item --win <integer>
+
+Specify the window size. The default is 50 bp.
+
+=item --num <integer>
+
+Specify the number of windows on either side of the feature position 
+(total number will be 2 x [num]). The default is 20, or 1 kb on either 
+side of the reference position if the default window size is used.
+
+=item --pos [5|m|3]
+
+Indicate the relative position of the feature around which the 
+data is mapped. Three values are accepted: "5" indicates the 
+5' prime end is used, "3" indicates the 3' end is used, and "m" 
+indicates the middle of the feature is used. The default is to 
+use the 5' end, or the start position of unstranded features. 
+
 =item --(no)sum
 
 Indicate that the data should be averaged across all features at
@@ -1460,12 +1474,6 @@ Default is true (sum).
 Indicate that windows without values should (not) be interpolated
 from neighboring values. The default is false (nosmooth).
 
-=item --log
-
-Dataset values are (not) in log2 space and should be treated 
-accordingly. Output values will be in the same space. The default is 
-false (nolog).
-
 =item --gz
 
 Specify whether (or not) the output file should be compressed with gzip.
@@ -1514,6 +1522,41 @@ features for each window is generated and written as a data row. This
 summed data may be graphed using the biotoolbox script L<graph_profile.pl> 
 or merged with other summed data sets for comparison.
 
+=head1 EXAMPLES
+
+These are some examples of some common scenarios for collecting data.
+
+=over 4
+
+=item Collect scores in intervals around start
+
+You want to collect the mean score from a bigWig file in twenty 50 bp 
+intervals flanking the start position of each feature in Bed file.
+
+  get_relative_data.pl --data scores.bw --in input.bed
+
+=item Collect scores in intervals around middle
+
+You want to collect median scores in 20 bp intervals extending 500 bp 
+from the midpoint of each feature.
+
+  get_relative_data.pl --win 20 --num 25 --pos m --data scores.bw --in \
+  input.txt
+
+=item Collect scores in intervals from annotation database
+
+You want to collect scores in intervals around the transcription start 
+site of genes in an annotation database, but also avoid intervals that 
+may overlap neighboring genes. You want to collect alignment counts 
+from a Bam file in a stranded fashion. You also want to plot the profile.
+
+  get_relative_data.pl --db annotation --feature gene --avoid --strand \
+  sense --value count --method sum --data alignments.bam --out gene_tss
+  
+  graph_profile.pl --in gene_tss_summed.txt --min 0 --max 100
+  
+=back
+
 =head1 AUTHOR
 
  Timothy J. Parnell, PhD
